## Weighted Finite State Transducers

This is a port of the n-best strings algorithm:

  Mohri, M. and Riley, M. 2002. __An efficient algorithm for the n-best-strings problem__. In Proc. ICSLP.

from [OpenFST](http://www.openfst.org) to Python 3.


## Running tests

```bash
python setup.py test

```
